objectbox_inspector_generator_plus library
Constants
- outputFile → const String
- The output file name for the generated code in the directory of your project.
Functions
-
mergeCodeAndProduceOutput(
BuilderOptions options) → Builder - A builder that merges the parsed entity code and produces the final output file.
-
parseEntitiesAndGenerateItsCode(
BuilderOptions options) → Builder - A builder that parses ObjectBox entities and generates inspection code.